==> inventive-inventory-1.3.2-sources.jar: net/inventive_mods/inventive_inventory/config/screens/widgets/ConfigProfileTitleWidget.java <==
package net.inventive_mods.inventive_inventory.config.screens.widgets;

import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.inventive_mods.inventive_inventory.util.widgets.CustomClickableWidget;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_7842;
import net.minecraft.class_7852;
import net.minecraft.class_8667;

public class ConfigProfileTitleWidget extends CustomClickableWidget {
    private final class_8667 horizontal = class_8667.method_52742().method_52735(10);

    public ConfigProfileTitleWidget(int width, int height) {
        super(width, height);
        class_310 client = InventiveInventory.getClient();
        String translationKey = "config.profiles.label.inventive_inventory.";
        this.horizontal.method_52736(class_7852.method_46512(client.field_1772.method_1727("1.")));
        this.horizontal.method_52736(new class_7842(80, height, class_2561.method_43471(translationKey + "name"), client.field_1772).method_48597());
        this.horizontal.method_52736(new class_7842(60, height, class_2561.method_43471(translationKey + "key"), client.field_1772).method_48597());
        this.horizontal.method_52736(new class_7842(205, height, class_2561.method_43471(translationKey + "preview"), client.field_1772).method_48597());
        this.horizontal.method_48222();
        this.field_22758 = this.horizontal.method_25368();
    }

    @Override
    protected void method_48579(class_332 context, int mouseX, int mouseY, float delta) {
        this.horizontal.method_48229(this.method_46426(), this.method_46427());
        this.horizontal.method_48206(clickableWidget -> clickableWidget.method_25394(context, mouseX, mouseY, delta));
    }
}

==> inventive-inventory-1.3.3-sources.jar: net/inventive_mods/inventive_inventory/config/screens/widgets/ConfigProfileTitleWidget.java <==
package net.inventive_mods.inventive_inventory.config.screens.widgets;

import net.inventive_mods.inventive_inventory.util.widgets.CenteredTextWidget;
import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.inventive_mods.inventive_inventory.util.widgets.CustomClickableWidget;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_7852;
import net.minecraft.class_8667;

public class ConfigProfileTitleWidget extends CustomClickableWidget {
    private final class_8667 horizontal = class_8667.method_52742().method_52735(10);

    public ConfigProfileTitleWidget(int width, int height) {
        super(width, height);
        class_310 client = InventiveInventory.getClient();
        String translationKey = "config.profiles.label.inventive_inventory.";
        this.horizontal.method_52736(class_7852.method_46512(client.field_1772.method_1727("1.")));
        this.horizontal.method_52736(new CenteredTextWidget(80, height, class_2561.method_43471(translationKey + "name"), client.field_1772));
        this.horizontal.method_52736(new CenteredTextWidget(60, height, class_2561.method_43471(translationKey + "key"), client.field_1772));
        this.horizontal.method_52736(new CenteredTextWidget(205, height, class_2561.method_43471(translationKey + "preview"), client.field_1772));
        this.horizontal.method_48222();
        this.field_22758 = this.horizontal.method_25368();
    }

    @Override
    protected void method_48579(class_332 context, int mouseX, int mouseY, float delta) {
        this.horizontal.method_48229(this.method_46426(), this.method_46427());
        this.horizontal.method_48206(clickableWidget -> clickableWidget.method_25394(context, mouseX, mouseY, delta));
    }
}
